@@ -27,7 +27,7 @@ from .http import BertHTTPProxy
 from .zmq_decor import multi_socket
 from .model_config import TransormerConfig
 __all__ = ['__version__', 'BertServer']
-__version__ = '1.13.1'
+__version__ = '1.13.2'
 import torch
 from transformers import *
 # _tf_ver_ = check_tf_version()
@@ -331,7 +331,7 @@ class BertSink(Process):
                     logger.error('received a wrongly-formatted request (expected 4 frames, got %d)' % len(msg))
                     logger.error('\n'.join('field %d: %s' % (idx, k) for idx, k in enumerate(msg)), exc_info=True)
 
-                logger.info('collect %s %s (E:%d/T:%d/A:%d)' % (msg[3], job_id,
+                logger.debug('collect %s %s (E:%d/T:%d/A:%d)' % (msg[3], job_id,
                                                                 pending_jobs[job_id].progress_embeds,
                                                                 pending_jobs[job_id].progress_tokens,
                                                                 pending_jobs[job_id].checksum))
@@ -357,7 +357,7 @@ class BertSink(Process):
                 client_addr, req_id = job_info.split(b'#')
                 x, x_info = tmp.result
                 sender.send_multipart([client_addr, x_info, x, req_id])
-                logger.info('send back\tsize: %d\tjob id: %s' % (tmp.checksum, job_info))
+                logger.debug('send back\tsize: %d\tjob id: %s' % (tmp.checksum, job_info))
                 # release the job
                 tmp.clear()
                 pending_jobs.pop(job_info)
@@ -570,7 +570,7 @@ class BertWorker(Process):
                     if sock in events:
                         client_id, raw_msg = sock.recv_multipart()
                         msg = jsonapi.loads(raw_msg)
-                        logger.info('new job\tsocket: %d\tsize: %d\tclient: %s' % (sock_idx, len(msg), client_id))
+                        logger.debug('new job\tsocket: %d\tsize: %d\tclient: %s' % (sock_idx, len(msg), client_id))
                         outputs = []
                         for sen in msg:
                             output = self.evaluate(sen)
